@@ -8,12 +8,12 @@ class Ling2MeRequest():
             'Content-Type': 'application/json',
             'Authorization': 'Bearer '+apikey
         }
-        data = {
+        payload = {
                 'text': source_text,  # text
                 'from': from_language,  # from language
                 'to': to_language,  # to language
             }
-        response = requests.post('https://app.ling2me.com/api/translate', headers=headers, data=data)
+        response = requests.post('https://app.ling2me.com/api/translate', data=json.dumps(payload), headers=headers)
         
         json_response = json.loads(response.text)
 
